﻿namespace R2Z.Shields.Printing.Test
{
    using System;
    using System.Collections.Generic;
    using System.IO.Ports;
    using System.Windows.Forms;

    public partial class Main : Form
    {
        
        public Main()
        {
            InitializeComponent();
            RefreshComPorts();
        }
        
        private void Print()
        {

            using (PrinterShield ps = new PrinterShield(cmbSerialPorts.SelectedValue.ToString()))
            {
                ps.Open();
                ps.PrintLine(txtInput.Text.TrimEnd(new char[] { '\r', '\n' }));
                ps.Close();
            }


            txtLog.AppendText(txtInput.Text + "\r\n");
            txtLog.SelectionStart = txtLog.Text.Length;
            txtLog.ScrollToCaret();

            txtInput.Text = "";

        }

        private void cmbSerialPorts_SelectedValueChanged(object sender, EventArgs e)
        {
            if (string.IsNullOrWhiteSpace(cmbSerialPorts.SelectedValue.ToString()))
            {
                lblPrinterInfo.Text = "PRINTER: NONE SELECTED";
                lblModel.Text = "MODEL: NONE SELECTED";
                txtInput.Enabled = false;
                btnPrint.Enabled = false;
                return;
            }

            try
            {

                using (PrinterShield ps = new PrinterShield(cmbSerialPorts.SelectedValue.ToString()))
                {
                    ps.Open();
                    string serialNumber = ps.GetSerialNumber();
                    lblPrinterInfo.Text = "PRINTER: " + serialNumber;
                    if (serialNumber.StartsWith("R2Z5000"))
                    {
                        lblModel.Text = "MODEL: Arduino Shield";
                    }
                    else if (serialNumber.StartsWith("R2Z5001"))
                    {
                        lblModel.Text = "MODEL: Raspberry Shield";
                    }
                    else
                    {
                        lblModel.Text = "MODEL: UNKNOWN";
                    }
                    ps.Close();
                }
            }
            catch
            {
                lblPrinterInfo.Text = "PRINTER: NO CONNECTION";
                lblModel.Text = "MODEL: NO CONNECTION";
                txtInput.Enabled = false;
                btnPrint.Enabled = false;
                return;
            }

            txtInput.Enabled = true;
            btnPrint.Enabled = true;

        }

        private void RefreshComPorts()
        {
            List<string> serialPorts = new List<string>();
            serialPorts.Add("");
            serialPorts.AddRange(SerialPort.GetPortNames());
            cmbSerialPorts.DataSource = serialPorts;
        }

        private void Main_Load(object sender, EventArgs e)
        {

        }
        private void btnRefreshComPorts_Click(object sender, EventArgs e)
        {
            RefreshComPorts();
        }
        private void txtInput_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == 13)
            {
                Print();
            }
        }

        private void btnPrint_Click(object sender, EventArgs e)
        {
            Print();
        }

        private void btnGecko_Click(object sender, EventArgs e)
        {
            using (PrinterShield ps = new PrinterShield(cmbSerialPorts.SelectedValue.ToString()))
            {
                ps.Open();
                ps.PrintImage(@"GECO.BMP");
                ps.Close();
            }
        }

        private void btnPrintInfo_Click(object sender, EventArgs e)
        {
            using (PrinterShield ps = new PrinterShield(cmbSerialPorts.SelectedValue.ToString()))
            {
                ps.Open();
                ps.PrintDeviceInfos();
                ps.Close();
            }
        }
    }
}
